"""This file contains metadata to help describe the featurizers.
"""

properties = {
    "3D-Descriptors": {
        "Asphericity": {
            "name": "asphericity",
            "dimensionality": "scalar",
            "type": "float",
            "units": "",
            "description": "Molecular asphericity",
            "citations": ["doi:10.1063/1.464689"],
        },
        "Eccentricity": {
            "name": "eccentricity",
            "dimensionality": "scalar",
            "type": "float",
            "units": "",
            "description": "Molecular eccentricity",
            "citations": ["doi:10.1002/9780470125861.ch5"],
        },
        "InertialShapeFactor": {
            "name": "inertial_shape_factor",
            "dimensionality": "scalar",
            "type": "float",
            "units": "",
            "description": "Inertial shape factor",
            "citations": ["doi:10.1002/9783527618279.ch37"],
        },
        "NPR1": {
            "name": "npr1",
            "dimensionality": "scalar",
            "type": "float",
            "units": "",
            "description": "Normalized principal moments ratio 1 (=I1/I3)",
            "citations": ["doi:10.1021/ci025599w"],
        },
        "NPR2": {
            "name": "npr2",
            "dimensionality": "scalar",
            "type": "float",
            "units": "",
            "description": "Normalized principal moments ratio 2 (=I2/I3)",
            "citations": ["doi:10.1021/ci025599w"],
        },
    },
    "2D-Descriptors": {
        # Feature names are extracted from rdkit.Chem.Descriptors.descList
        "MaxEStateIndex": {
            "name": "max_e_state_index",
            "dimensionality": "scalar",
            "type": "float",
            "units": "",
            "description": "Maximum value of the electrotopological state atom index",
            "citations": ["rdkit_website"],
        },
        "MinEStateIndex": {
            "name": "min_e_state_index",
            "dimensionality": "scalar",
            "type": "float",
            "units": "",
            "description": "Minimum value of the electrotopological state atom index",
            "citations": ["rdkit_website"],
        },
        "MaxAbsEStateIndex": {
            "name": "max_abs_e_state_index",
            "dimensionality": "scalar",
            "type": "float",
            "units": "",
            "description": (
                "Maximum absolute value of the electrotopological state atom index"
            ),
            "citations": ["rdkit_website"],
        },
        "MinAbsEStateIndex": {
            "name": "min_abs_e_state_index",
            "dimensionality": "scalar",
            "type": "float",
            "units": "",
            "description": (
                "Minimum absolute value of the electrotopological state atom index"
            ),
            "citations": ["rdkit_website"],
        },
        "qed": {
            "name": "qed",
            "dimensionality": "scalar",
            "type": "float",
            "units": "",
            "description": "Quantitative estimation of drug-likeness",
            "citations": ["rdkit_website"],
        },
        "MolWt": {
            "name": "mol_wt",
            "dimensionality": "scalar",
            "type": "float",
            "units": "a.u.",
            "description": "Average molecular weight",
            "citations": ["rdkit_website"],
        },
        "HeavyAtomMolWt": {
            "name": "heavy_atom_mol_wt",
            "dimensionality": "scalar",
            "type": "float",
            "units": "a.u.",
            "description": "Average molecular weight ignoring hydrogens",
            "citations": ["rdkit_website"],
        },
        "ExactMolWt": {
            "name": "exact_mol_wt",
            "dimensionality": "scalar",
            "type": "float",
            "units": "a.u.",
            "description": "The exact molecular weight",
            "citations": [],
        },
        "NumValenceElectrons": {
            "name": "num_valence_electrons",
            "dimensionality": "scalar",
            "type": "int",
            "units": "",
            "description": "The number of valence electrons in the molecule",
            "citations": ["rdkit_website"],
        },
        "NumRadicalElectrons": {
            "name": "num_radical_electrons",
            "dimensionality": "scalar",
            "type": "int",
            "units": "",
            "description": (
                "The number of radical electrons in the "
                "molecule (regardless of their spin)"
            ),
            "citations": ["rdkit_website"],
        },
        "MaxPartialCharge": {
            "name": "max_partial_charge",
            "dimensionality": "scalar",
            "type": "float",
            "units": "a.u.",
            "description": "Maximum partial charge on the molecule",
            "citations": ["GASTEIGER19803219"],
        },
        "MinPartialCharge": {
            "name": "min_partial_charge",
            "dimensionality": "scalar",
            "type": "float",
            "units": "a.u.",
            "description": "Minimum partial charge on the molecule",
            "citations": ["GASTEIGER19803219"],
        },
        "MaxAbsPartialCharge": {
            "name": "max_abs_partial_charge",
            "dimensionality": "scalar",
            "type": "float",
            "units": "a.u.",
            "description": "Maximum absolute value of partial charge on the molecule",
            "citations": ["GASTEIGER19803219"],
        },
        "MinAbsPartialCharge": {
            "name": "min_abs_partial_charge",
            "dimensionality": "scalar",
            "type": "float",
            "units": "a.u.",
            "description": "Minimum absolute value of partial charge on the molecule",
            "citations": ["GASTEIGER19803219"],
        },
        "FpDensityMorgan1": {
            "name": "fp_density_morgan1",
            "dimensionality": "scalar",
            "type": "float",
            "units": "",
            "description": "Morgan-1 density fingerprint",
            "citations": ["doi:10.1021/ci100050t"],
        },
        "FpDensityMorgan2": {
            "name": "fp_density_morgan2",
            "dimensionality": "scalar",
            "type": "float",
            "units": "",
            "description": "Morgan-2 density fingerprint",
            "citations": ["doi:10.1021/ci100050t"],
        },
        "FpDensityMorgan3": {
            "name": "fp_density_morgan3",
            "dimensionality": "scalar",
            "type": "float",
            "units": "",
            "description": "Morgan-3 density fingerprint",
            "citations": ["doi:10.1021/ci100050t"],
        },
        "BCUT2D_MWHI": {
            "name": "bcut2d_mwhi",
            "dimensionality": "scalar",
            "type": "float",
            "units": "",
            "description": "",
            "citations": ["Pearlman_1997"],
        },
        "BCUT2D_MWLOW": {
            "name": "bcut2d_mwlow",
            "dimensionality": "scalar",
            "type": "float",
            "units": "",
            "description": "",
            "citations": ["Pearlman_1997"],
        },
        "BCUT2D_CHGHI": {
            "name": "bcut2d_chghi",
            "dimensionality": "scalar",
            "type": "float",
            "units": "",
            "description": "",
            "citations": ["Pearlman_1997"],
        },
        "BCUT2D_CHGLO": {
            "name": "bcut2d_chglo",
            "dimensionality": "scalar",
            "type": "float",
            "units": "",
            "description": "",
            "citations": ["Pearlman_1997"],
        },
        "BCUT2D_LOGPHI": {
            "name": "bcut2d_logphi",
            "dimensionality": "scalar",
            "type": "float",
            "units": "",
            "description": "",
            "citations": ["Pearlman_1997"],
        },
        "BCUT2D_LOGPLOW": {
            "name": "bcut2d_logplow",
            "dimensionality": "scalar",
            "type": "float",
            "units": "",
            "description": "",
            "citations": ["Pearlman_1997"],
        },
        "BCUT2D_MRHI": {
            "name": "bcut2d_mrhi",
            "dimensionality": "scalar",
            "type": "float",
            "units": "",
            "description": "",
            "citations": ["Pearlman_1997"],
        },
        "BCUT2D_MRLOW": {
            "name": "bcut2d_mrlow",
            "dimensionality": "scalar",
            "type": "float",
            "units": "",
            "description": "",
            "citations": ["Pearlman_1997"],
        },
        "BalabanJ": {
            "name": "balaban_j",
            "dimensionality": "scalar",
            "type": "float",
            "units": "",
            "description": "Balaban's J value for a molecule",
            "citations": ["BALABAN1982399"],
        },
        "BertzCT": {
            "name": "bertz_ct",
            "dimensionality": "scalar",
            "type": "float",
            "units": "",
            "description": "Topological complexity index of a molecule",
            "citations": ["doi:10.1021/ja00402a071"],
        },
        "Chi0": {
            "name": "chi0",
            "dimensionality": "scalar",
            "type": "float",
            "units": "",
            "description": "Chi-0 graph descriptor",
            "citations": ["doi:https://doi.org/10.1002/9780470125793.ch9"],
        },
        "Chi0n": {
            "name": "chi0n",
            "dimensionality": "scalar",
            "type": "float",
            "units": "",
            "description": "Chi-0n graph descriptor",
            "citations": ["doi:https://doi.org/10.1002/9780470125793.ch9"],
        },
        "Chi0v": {
            "name": "chi0v",
            "dimensionality": "scalar",
            "type": "float",
            "units": "",
            "description": "Chi-0v graph descriptor",
            "citations": ["doi:https://doi.org/10.1002/9780470125793.ch9"],
        },
        "Chi1": {
            "name": "chi1",
            "dimensionality": "scalar",
            "type": "float",
            "units": "",
            "description": "Chi-1 graph descriptor",
            "citations": ["doi:https://doi.org/10.1002/9780470125793.ch9"],
        },
        "Chi1n": {
            "name": "chi1n",
            "dimensionality": "scalar",
            "type": "float",
            "units": "",
            "description": "Chi-1n graph descriptor",
            "citations": ["doi:https://doi.org/10.1002/9780470125793.ch9"],
        },
        "Chi1v": {
            "name": "chi1v",
            "dimensionality": "scalar",
            "type": "float",
            "units": "",
            "description": "Chi-1v graph descriptor",
            "citations": ["doi:https://doi.org/10.1002/9780470125793.ch9"],
        },
        "Chi2n": {
            "name": "chi2n",
            "dimensionality": "scalar",
            "type": "float",
            "units": "",
            "description": "Chi-2n graph descriptor",
            "citations": ["doi:https://doi.org/10.1002/9780470125793.ch9"],
        },
        "Chi2v": {
            "name": "chi2v",
            "dimensionality": "scalar",
            "type": "float",
            "units": "",
            "description": "Chi-2v graph descriptor",
            "citations": ["doi:https://doi.org/10.1002/9780470125793.ch9"],
        },
        "Chi3n": {
            "name": "chi3n",
            "dimensionality": "scalar",
            "type": "float",
            "units": "",
            "description": "Chi-3n graph descriptor",
            "citations": ["doi:https://doi.org/10.1002/9780470125793.ch9"],
        },
        "Chi3v": {
            "name": "chi3v",
            "dimensionality": "scalar",
            "type": "float",
            "units": "",
            "description": "Chi-3v graph descriptor",
            "citations": ["doi:https://doi.org/10.1002/9780470125793.ch9"],
        },
        "Chi4n": {
            "name": "chi4n",
            "dimensionality": "scalar",
            "type": "float",
            "units": "",
            "description": "Chi-4n graph descriptor",
            "citations": ["doi:https://doi.org/10.1002/9780470125793.ch9"],
        },
        "Chi4v": {
            "name": "chi4v",
            "dimensionality": "scalar",
            "type": "float",
            "units": "",
            "description": "Chi-4v graph descriptor",
            "citations": ["doi:https://doi.org/10.1002/9780470125793.ch9"],
        },
        "HallKierAlpha": {
            "name": "hall_kier_alpha",
            "dimensionality": "scalar",
            "type": "float",
            "units": "",
            "description": "",
            "citations": ["doi:https://doi.org/10.1002/9780470125793.ch9"],
        },
        "Ipc": {
            "name": "ipc",
            "dimensionality": "scalar",
            "type": "float",
            "units": "",
            "description": (
                "the information content of the coefficients of the "
                "characteristicpolynomial of the adjacency matrix of a "
                "hydrogen-suppressed graph of a molecule"
            ),
            "citations": ["doi:10.1063/1.434593"],
        },
        "Kappa1": {
            "name": "kappa1",
            "dimensionality": "scalar",
            "type": "float",
            "units": "",
            "description": "",
            "citations": ["doi:https://doi.org/10.1002/9780470125793.ch9"],
        },
        "Kappa2": {
            "name": "kappa2",
            "dimensionality": "scalar",
            "type": "float",
            "units": "",
            "description": "",
            "citations": ["doi:https://doi.org/10.1002/9780470125793.ch9"],
        },
        "Kappa3": {
            "name": "kappa3",
            "dimensionality": "scalar",
            "type": "float",
            "units": "",
            "description": "",
            "citations": ["doi:https://doi.org/10.1002/9780470125793.ch9"],
        },
        "LabuteASA": {
            "name": "labute_asa",
            "dimensionality": "scalar",
            "type": "float",
            "units": "",
            "description": "",
            "citations": ["LABUTE2000464"],
        },
        "PEOE_VSA1": {
            "name": "peoe_vsa1",
            "dimensionality": "scalar",
            "type": "float",
            "units": "",
            "description": "MOE Charge VSA Descriptor-1 (-inf < x < -0.30)",
            "citations": ["moe_website"],
        },
        "PEOE_VSA10": {
            "name": "peoe_vsa10",
            "dimensionality": "scalar",
            "type": "float",
            "units": "",
            "description": "MOE Charge VSA Descriptor-10 ( 0.10 <= x <  0.15)",
            "citations": ["moe_website"],
        },
        "PEOE_VSA11": {
            "name": "peoe_vsa11",
            "dimensionality": "scalar",
            "type": "float",
            "units": "",
            "description": "MOE Charge VSA Descriptor-11 ( 0.15 <= x <  0.20)",
            "citations": ["moe_website"],
        },
        "PEOE_VSA12": {
            "name": "peoe_vsa12",
            "dimensionality": "scalar",
            "type": "float",
            "units": "",
            "description": "MOE Charge VSA Descriptor-12 ( 0.20 <= x <  0.25)",
            "citations": ["moe_website"],
        },
        "PEOE_VSA13": {
            "name": "peoe_vsa13",
            "dimensionality": "scalar",
            "type": "float",
            "units": "",
            "description": "MOE Charge VSA Descriptor-13 ( 0.25 <= x <  0.30)",
            "citations": ["moe_website"],
        },
        "PEOE_VSA14": {
            "name": "peoe_vsa14",
            "dimensionality": "scalar",
            "type": "float",
            "units": "",
            "description": "MOE Charge VSA Descriptor-14 ( 0.30 <= x < inf)",
            "citations": ["moe_website"],
        },
        "PEOE_VSA2": {
            "name": "peoe_vsa2",
            "dimensionality": "scalar",
            "type": "float",
            "units": "",
            "description": "MOE Charge VSA Descriptor-2 (-0.30 <= x < -0.25)",
            "citations": ["moe_website"],
        },
        "PEOE_VSA3": {
            "name": "peoe_vsa3",
            "dimensionality": "scalar",
            "type": "float",
            "units": "",
            "description": "MOE Charge VSA Descriptor-3 (-0.25 <= x < -0.20)",
            "citations": ["moe_website"],
        },
        "PEOE_VSA4": {
            "name": "peoe_vsa4",
            "dimensionality": "scalar",
            "type": "float",
            "units": "",
            "description": "MOE Charge VSA Descriptor-4 (-0.20 <= x < -0.15)",
            "citations": ["moe_website"],
        },
        "PEOE_VSA5": {
            "name": "peoe_vsa5",
            "dimensionality": "scalar",
            "type": "float",
            "units": "",
            "description": "MOE Charge VSA Descriptor-5 (-0.15 <= x < -0.10)",
            "citations": ["moe_website"],
        },
        "PEOE_VSA6": {
            "name": "peoe_vsa6",
            "dimensionality": "scalar",
            "type": "float",
            "units": "",
            "description": "MOE Charge VSA Descriptor-6 (-0.10 <= x < -0.05)",
            "citations": ["moe_website"],
        },
        "PEOE_VSA7": {
            "name": "peoe_vsa7",
            "dimensionality": "scalar",
            "type": "float",
            "units": "",
            "description": "MOE Charge VSA Descriptor-7 (-0.05 <= x <  0.00)",
            "citations": ["moe_website"],
        },
        "PEOE_VSA8": {
            "name": "peoe_vsa8",
            "dimensionality": "scalar",
            "type": "float",
            "units": "",
            "description": "MOE Charge VSA Descriptor-8 ( 0.00 <= x <  0.05)",
            "citations": ["moe_website"],
        },
        "PEOE_VSA9": {
            "name": "peoe_vsa9",
            "dimensionality": "scalar",
            "type": "float",
            "units": "",
            "description": "MOE Charge VSA Descriptor-9 ( 0.05 <= x <  0.10)",
            "citations": ["moe_website"],
        },
        "SMR_VSA1": {
            "name": "smr_vsa1",
            "dimensionality": "scalar",
            "type": "float",
            "units": "",
            "description": "MOE MR VSA Descriptor-1 (-inf < x <  1.29)",
            "citations": ["moe_website"],
        },
        "SMR_VSA10": {
            "name": "smr_vsa10",
            "dimensionality": "scalar",
            "type": "float",
            "units": "",
            "description": "MOE MR VSA Descriptor-10 ( 4.00 <= x < inf)",
            "citations": ["moe_website"],
        },
        "SMR_VSA2": {
            "name": "smr_vsa2",
            "dimensionality": "scalar",
            "type": "float",
            "units": "",
            "description": "MOE MR VSA Descriptor-2 ( 1.29 <= x <  1.82)",
            "citations": ["moe_website"],
        },
        "SMR_VSA3": {
            "name": "smr_vsa3",
            "dimensionality": "scalar",
            "type": "float",
            "units": "",
            "description": "MOE MR VSA Descriptor-3 ( 1.82 <= x <  2.24)",
            "citations": ["moe_website"],
        },
        "SMR_VSA4": {
            "name": "smr_vsa4",
            "dimensionality": "scalar",
            "type": "float",
            "units": "",
            "description": "MOE MR VSA Descriptor-4 ( 2.24 <= x <  2.45)",
            "citations": ["moe_website"],
        },
        "SMR_VSA5": {
            "name": "smr_vsa5",
            "dimensionality": "scalar",
            "type": "float",
            "units": "",
            "description": "MOE MR VSA Descriptor-5 ( 2.45 <= x <  2.75)",
            "citations": ["moe_website"],
        },
        "SMR_VSA6": {
            "name": "smr_vsa6",
            "dimensionality": "scalar",
            "type": "float",
            "units": "",
            "description": "MOE MR VSA Descriptor-6 ( 2.75 <= x <  3.05)",
            "citations": ["moe_website"],
        },
        "SMR_VSA7": {
            "name": "smr_vsa7",
            "dimensionality": "scalar",
            "type": "float",
            "units": "",
            "description": "MOE MR VSA Descriptor-7 ( 3.05 <= x <  3.63)",
            "citations": ["moe_website"],
        },
        "SMR_VSA8": {
            "name": "smr_vsa8",
            "dimensionality": "scalar",
            "type": "float",
            "units": "",
            "description": "MOE MR VSA Descriptor-8 ( 3.63 <= x <  3.80)",
            "citations": ["moe_website"],
        },
        "SMR_VSA9": {
            "name": "smr_vsa9",
            "dimensionality": "scalar",
            "type": "float",
            "units": "",
            "description": "MOE MR VSA Descriptor-9 ( 3.80 <= x <  4.00)",
            "citations": ["moe_website"],
        },
        "SlogP_VSA1": {
            "name": "slogp_vsa1",
            "dimensionality": "scalar",
            "type": "float",
            "units": "",
            "description": "MOE logP VSA Descriptor-1 (-inf < x < -0.40)",
            "citations": ["moe_website"],
        },
        "SlogP_VSA10": {
            "name": "slogp_vsa10",
            "dimensionality": "scalar",
            "type": "float",
            "units": "",
            "description": "MOE logP VSA Descriptor-10 ( 0.40 <= x <  0.50)",
            "citations": ["moe_website"],
        },
        "SlogP_VSA11": {
            "name": "slogp_vsa11",
            "dimensionality": "scalar",
            "type": "float",
            "units": "",
            "description": "MOE logP VSA Descriptor-11 ( 0.50 <= x <  0.60)",
            "citations": ["moe_website"],
        },
        "SlogP_VSA12": {
            "name": "slogp_vsa12",
            "dimensionality": "scalar",
            "type": "float",
            "units": "",
            "description": "MOE logP VSA Descriptor-12 ( 0.60 <= x < inf)",
            "citations": ["moe_website"],
        },
        "SlogP_VSA2": {
            "name": "slogp_vsa2",
            "dimensionality": "scalar",
            "type": "float",
            "units": "",
            "description": "MOE logP VSA Descriptor-2 (-0.40 <= x < -0.20)",
            "citations": ["moe_website"],
        },
        "SlogP_VSA3": {
            "name": "slogp_vsa3",
            "dimensionality": "scalar",
            "type": "float",
            "units": "",
            "description": "MOE logP VSA Descriptor-3 (-0.20 <= x <  0.00)",
            "citations": ["moe_website"],
        },
        "SlogP_VSA4": {
            "name": "slogp_vsa4",
            "dimensionality": "scalar",
            "type": "float",
            "units": "",
            "description": "MOE logP VSA Descriptor-4 ( 0.00 <= x <  0.10)",
            "citations": ["moe_website"],
        },
        "SlogP_VSA5": {
            "name": "slogp_vsa5",
            "dimensionality": "scalar",
            "type": "float",
            "units": "",
            "description": "MOE logP VSA Descriptor-5 ( 0.10 <= x <  0.15)",
            "citations": ["moe_website"],
        },
        "SlogP_VSA6": {
            "name": "slogp_vsa6",
            "dimensionality": "scalar",
            "type": "float",
            "units": "",
            "description": "MOE logP VSA Descriptor-6 ( 0.15 <= x <  0.20)",
            "citations": ["moe_website"],
        },
        "SlogP_VSA7": {
            "name": "slogp_vsa7",
            "dimensionality": "scalar",
            "type": "float",
            "units": "",
            "description": "MOE logP VSA Descriptor-7 ( 0.20 <= x <  0.25)",
            "citations": ["moe_website"],
        },
        "SlogP_VSA8": {
            "name": "slogp_vsa8",
            "dimensionality": "scalar",
            "type": "float",
            "units": "",
            "description": "MOE logP VSA Descriptor-8 ( 0.25 <= x <  0.30)",
            "citations": ["moe_website"],
        },
        "SlogP_VSA9": {
            "name": "slogp_vsa9",
            "dimensionality": "scalar",
            "type": "float",
            "units": "",
            "description": "MOE logP VSA Descriptor-9 ( 0.30 <= x <  0.40)",
            "citations": ["moe_website"],
        },
        # "TPSA": {
        #     "name": "tpsa",
        #     "dimensionality": "scalar",
        #     "type": "float",
        #     "units": "",
        #     "description": "Topological polar surface area (TPSA) of a molecule",
        #     "citations": ["doi:10.1021/jm000942e"],
        # },
        "EState_VSA1": {
            "name": "estate_vsa1",
            "dimensionality": "scalar",
            "type": "float",
            "units": "",
            "description": "EState VSA Descriptor-1 (-inf < x <  -0.39)",
            "citations": ["moe_website"],
        },
        "EState_VSA10": {
            "name": "estate_vsa10",
            "dimensionality": "scalar",
            "type": "float",
            "units": "",
            "description": "EState VSA Descriptor-10 ( 9.17 <= x <  15.00)",
            "citations": ["moe_website"],
        },
        "EState_VSA11": {
            "name": "estate_vsa11",
            "dimensionality": "scalar",
            "type": "float",
            "units": "",
            "description": "EState VSA Descriptor-11 ( 15.00 <= x < inf)",
            "citations": ["moe_website"],
        },
        "EState_VSA2": {
            "name": "estate_vsa2",
            "dimensionality": "scalar",
            "type": "float",
            "units": "",
            "description": "EState VSA Descriptor-2 ( -0.39 <= x <  0.29)",
            "citations": ["moe_website"],
        },
        "EState_VSA3": {
            "name": "estate_vsa3",
            "dimensionality": "scalar",
            "type": "float",
            "units": "",
            "description": "EState VSA Descriptor-3 ( 0.29 <= x <  0.72)",
            "citations": ["moe_website"],
        },
        "EState_VSA4": {
            "name": "estate_vsa4",
            "dimensionality": "scalar",
            "type": "float",
            "units": "",
            "description": "EState VSA Descriptor-4 ( 0.72 <= x <  1.17)",
            "citations": ["moe_website"],
        },
        "EState_VSA5": {
            "name": "estate_vsa5",
            "dimensionality": "scalar",
            "type": "float",
            "units": "",
            "description": "EState VSA Descriptor-5 ( 1.17 <= x <  1.54)",
            "citations": ["moe_website"],
        },
        "EState_VSA6": {
            "name": "estate_vsa6",
            "dimensionality": "scalar",
            "type": "float",
            "units": "",
            "description": "EState VSA Descriptor-6 ( 1.54 <= x <  1.81)",
            "citations": ["moe_website"],
        },
        "EState_VSA7": {
            "name": "estate_vsa7",
            "dimensionality": "scalar",
            "type": "float",
            "units": "",
            "description": "EState VSA Descriptor-7 ( 1.81 <= x <  2.05)",
            "citations": ["moe_website"],
        },
        "EState_VSA8": {
            "name": "estate_vsa8",
            "dimensionality": "scalar",
            "type": "float",
            "units": "",
            "description": "EState VSA Descriptor-8 ( 2.05 <= x <  4.69)",
            "citations": ["moe_website"],
        },
        "EState_VSA9": {
            "name": "estate_vsa9",
            "dimensionality": "scalar",
            "type": "float",
            "units": "",
            "description": "EState VSA Descriptor-9 ( 4.69 <= x <  9.17)",
            "citations": ["moe_website"],
        },
        "VSA_EState1": {
            "name": "vsa_estate1",
            "dimensionality": "scalar",
            "type": "float",
            "units": "",
            "description": "VSA EState Descriptor-1 (-inf < x <  4.78)",
            "citations": ["moe_website"],
        },
        "VSA_EState10": {
            "name": "vsa_estate10",
            "dimensionality": "scalar",
            "type": "float",
            "units": "VSA EState Descriptor-10 ( 11.00 <= x < inf)",
            "description": "",
            "citations": ["moe_website"],
        },
        "VSA_EState2": {
            "name": "vsa_estate2",
            "dimensionality": "scalar",
            "type": "float",
            "units": "",
            "description": "VSA EState Descriptor-2 ( 4.78 <= x <  5.00)",
            "citations": ["moe_website"],
        },
        "VSA_EState3": {
            "name": "vsa_estate3",
            "dimensionality": "scalar",
            "type": "float",
            "units": "",
            "description": "VSA EState Descriptor-3 ( 5.00 <= x <  5.41)",
            "citations": ["moe_website"],
        },
        "VSA_EState4": {
            "name": "vsa_estate4",
            "dimensionality": "scalar",
            "type": "float",
            "units": "",
            "description": "VSA EState Descriptor-4 ( 5.41 <= x <  5.74)",
            "citations": ["moe_website"],
        },
        "VSA_EState5": {
            "name": "vsa_estate5",
            "dimensionality": "scalar",
            "type": "float",
            "units": "",
            "description": "VSA EState Descriptor-5 ( 5.74 <= x <  6.00)",
            "citations": ["moe_website"],
        },
        "VSA_EState6": {
            "name": "vsa_estate6",
            "dimensionality": "scalar",
            "type": "float",
            "units": "",
            "description": "VSA EState Descriptor-6 ( 6.00 <= x <  6.07)",
            "citations": ["moe_website"],
        },
        "VSA_EState7": {
            "name": "vsa_estate7",
            "dimensionality": "scalar",
            "type": "float",
            "units": "",
            "description": "VSA EState Descriptor-7 ( 6.07 <= x <  6.45)",
            "citations": ["moe_website"],
        },
        "VSA_EState8": {
            "name": "vsa_estate8",
            "dimensionality": "scalar",
            "type": "float",
            "units": "",
            "description": "VSA EState Descriptor-8 ( 6.45 <= x <  7.00)",
            "citations": ["moe_website"],
        },
        "VSA_EState9": {
            "name": "vsa_estate9",
            "dimensionality": "scalar",
            "type": "float",
            "units": "",
            "description": "VSA EState Descriptor-9 ( 7.00 <= x <  11.00)",
            "citations": ["moe_website"],
        },
        "FractionCSP3": {
            "name": "fraction_csp3",
            "dimensionality": "scalar",
            "type": "float",
            "units": "",
            "description": "Fraction of sp3 hybridized C atoms in the molecule",
            "citations": ["rdkit_website"],
        },
        "HeavyAtomCount": {
            "name": "heavy_atom_count",
            "dimensionality": "scalar",
            "type": "int",
            "units": "",
            "description": "Number of heavy atoms in the molecule",
            "citations": ["https://doi.org/10.1002/cmdc.200900317"],
        },
        "NHOHCount": {
            "name": "nhoh_count",
            "dimensionality": "scalar",
            "type": "int",
            "units": "",
            "description": "Number of NH or OH groups in a molecule",
            "citations": ["https://doi.org/10.1002/cmdc.200900317"],
        },
        "NOCount": {
            "name": "no_count",
            "dimensionality": "scalar",
            "type": "int",
            "units": "",
            "description": "Number of nitrogens and oxygens in a molecule",
            "citations": ["https://doi.org/10.1002/cmdc.200900317"],
        },
        "NumAliphaticCarbocycles": {
            "name": "num_aliphatic_carbocycles",
            "dimensionality": "scalar",
            "type": "int",
            "units": "",
            "description": (
                "Number of aliphatic (containing at least one "
                "non-aromatic bond) carbocycles in a molecule"
            ),
            "citations": ["https://doi.org/10.1002/cmdc.200900317"],
        },
        "NumAliphaticHeterocycles": {
            "name": "num_aliphatic_heterocycles",
            "dimensionality": "scalar",
            "type": "int",
            "units": "",
            "description": (
                "Number of aliphatic (containing at least one "
                "non-aromatic bond) heterocycles in a molecule"
            ),
            "citations": ["https://doi.org/10.1002/cmdc.200900317"],
        },
        "NumAliphaticRings": {
            "name": "num_aliphatic_rings",
            "dimensionality": "scalar",
            "type": "int",
            "units": "",
            "description": (
                "Number of aliphatic (containing at least one "
                "non-aromatic bond) rings in a molecule"
            ),
            "citations": ["https://doi.org/10.1002/cmdc.200900317"],
        },
        "NumAromaticCarbocycles": {
            "name": "num_aromatic_carbocycles",
            "dimensionality": "scalar",
            "type": "int",
            "units": "",
            "description": "Number of aromatic carbocycles in a molecule",
            "citations": ["https://doi.org/10.1002/cmdc.200900317"],
        },
        "NumAromaticHeterocycles": {
            "name": "num_aromatic_heterocycles",
            "dimensionality": "scalar",
            "type": "int",
            "units": "",
            "description": "Number of aromatic heterocycles in a molecule",
            "citations": ["https://doi.org/10.1002/cmdc.200900317"],
        },
        "NumAromaticRings": {
            "name": "num_aromatic_rings",
            "dimensionality": "scalar",
            "type": "int",
            "units": "",
            "description": "Number of aromatic rings in a molecule",
            "citations": ["https://doi.org/10.1002/cmdc.200900317"],
        },
        "NumHAcceptors": {
            "name": "num_h_acceptors",
            "dimensionality": "scalar",
            "type": "int",
            "units": "",
            "description": "Number of hydrogen bond acceptors",
            "citations": ["https://doi.org/10.1002/cmdc.200900317"],
        },
        "NumHDonors": {
            "name": "num_h_donors",
            "dimensionality": "scalar",
            "type": "int",
            "units": "",
            "description": "Number of hydrogen bond donors",
            "citations": ["https://doi.org/10.1002/cmdc.200900317"],
        },
        "NumHeteroatoms": {
            "name": "num_heteroatoms",
            "dimensionality": "scalar",
            "type": "int",
            "units": "",
            "description": "Number of heteroatoms",
            "citations": ["https://doi.org/10.1002/cmdc.200900317"],
        },
        "NumRotatableBonds": {
            "name": "num_rotatable_bonds",
            "dimensionality": "scalar",
            "type": "int",
            "units": "",
            "description": "Number of rotatable bonds",
            "citations": ["https://doi.org/10.1002/cmdc.200900317"],
        },
        "NumSaturatedCarbocycles": {
            "name": "num_saturated_carbocycles",
            "dimensionality": "scalar",
            "type": "int",
            "units": "",
            "description": "Number of saturated carbocycles in the molecule",
            "citations": ["https://doi.org/10.1002/cmdc.200900317"],
        },
        "NumSaturatedHeterocycles": {
            "name": "num_saturated_heterocycles",
            "dimensionality": "scalar",
            "type": "int",
            "units": "",
            "description": "Number of saturated heterocycles in the molecule",
            "citations": ["https://doi.org/10.1002/cmdc.200900317"],
        },
        "NumSaturatedRings": {
            "name": "num_saturated_rings",
            "dimensionality": "scalar",
            "type": "int",
            "units": "",
            "description": "Number of saturated rings in the molecule",
            "citations": ["https://doi.org/10.1002/cmdc.200900317"],
        },
        "RingCount": {
            "name": "ring_count",
            "dimensionality": "scalar",
            "type": "int",
            "units": "",
            "description": "Number of rings",
            "citations": ["https://doi.org/10.1002/cmdc.200900317"],
        },
        "MolLogP": {
            "name": "mol_logp",
            "dimensionality": "scalar",
            "type": "float",
            "units": "",
            "description": "Wildman-Crippen LogP value",
            "citations": ["doi:10.1021/ci990307l"],
        },
        "MolMR": {
            "name": "log_mr",
            "dimensionality": "scalar",
            "type": "float",
            "units": "",
            "description": "Wildman-Crippen MR value",
            "citations": ["doi:10.1021/ci990307l"],
        },
        "fr_Al_COO": {
            "name": "fr_al_coo",
            "dimensionality": "scalar",
            "type": "int",
            "units": "",
            "description": "Number of aliphatic carboxylic acids",
            "citations": ["rdkit_website"],
        },
        "fr_Al_OH": {
            "name": "fr_al_oh",
            "dimensionality": "scalar",
            "type": "int",
            "units": "",
            "description": "Number of aliphatic hydroxyl groups",
            "citations": ["rdkit_website"],
        },
        "fr_Al_OH_noTert": {
            "name": "fr_al_oh_no_tert",
            "dimensionality": "scalar",
            "type": "int",
            "units": "",
            "description": "Number of aliphatic hydroxyl groups excluding tert-OH",
            "citations": ["rdkit_website"],
        },
        "fr_ArN": {
            "name": "fr_arn",
            "dimensionality": "scalar",
            "type": "int",
            "units": "",
            "description": "Number of N functional groups attached to aromatics",
            "citations": ["rdkit_website"],
        },
        "fr_Ar_COO": {
            "name": "fr_ar_coo",
            "dimensionality": "scalar",
            "type": "int",
            "units": "",
            "description": "Number of aromatic carboxylic acid groups",
            "citations": ["rdkit_website"],
        },
        "fr_Ar_N": {
            "name": "fr_ar_n",
            "dimensionality": "scalar",
            "type": "int",
            "units": "",
            "description": "Number of aromatic nitrogens",
            "citations": ["rdkit_website"],
        },
        "fr_Ar_NH": {
            "name": "fr_ar_nh",
            "dimensionality": "scalar",
            "type": "int",
            "units": "",
            "description": "Number of aromatic amines",
            "citations": ["rdkit_website"],
        },
        "fr_Ar_OH": {
            "name": "fr_ar_oh",
            "dimensionality": "scalar",
            "type": "int",
            "units": "",
            "description": "Number of aromatic hydroxyl groups",
            "citations": ["rdkit_website"],
        },
        "fr_COO": {
            "name": "fr_coo",
            "dimensionality": "scalar",
            "type": "int",
            "units": "",
            "description": "Number of carboxylic acids",
            "citations": ["rdkit_website"],
        },
        "fr_COO2": {
            "name": "fr_coo2",
            "dimensionality": "scalar",
            "type": "int",
            "units": "",
            "description": "Number of carboxylic acids-2",
            "citations": ["rdkit_website"],
        },
        "fr_C_O": {
            "name": "fr_c_o",
            "dimensionality": "scalar",
            "type": "int",
            "units": "",
            "description": "Number of carbonyl O",
            "citations": ["rdkit_website"],
        },
        "fr_C_O_noCOO": {
            "name": "fr_c_o_no_coo",
            "dimensionality": "scalar",
            "type": "int",
            "units": "",
            "description": "Number of carbonyl O, excluding COOH",
            "citations": ["rdkit_website"],
        },
        "fr_C_S": {
            "name": "fr_c_s",
            "dimensionality": "scalar",
            "type": "int",
            "units": "",
            "description": "Number of thiocarbonyl",
            "citations": ["rdkit_website"],
        },
        "fr_HOCCN": {
            "name": "fr_hoccn",
            "dimensionality": "scalar",
            "type": "int",
            "units": "",
            "description": "Number of C(OH)CCN-Ctert-alkyl or C(OH)CCNcyclic",
            "citations": ["rdkit_website"],
        },
        "fr_Imine": {
            "name": "fr_imine",
            "dimensionality": "scalar",
            "type": "int",
            "units": "",
            "description": "Number of imines",
            "citations": ["rdkit_website"],
        },
        "fr_NH0": {
            "name": "fr_nh0",
            "dimensionality": "scalar",
            "type": "int",
            "units": "",
            "description": "Number of tertiary amines",
            "citations": ["rdkit_website"],
        },
        "fr_NH1": {
            "name": "fr_nh1",
            "dimensionality": "scalar",
            "type": "int",
            "units": "",
            "description": "Number of secondary amines",
            "citations": ["rdkit_website"],
        },
        "fr_NH2": {
            "name": "fr_nh2",
            "dimensionality": "scalar",
            "type": "int",
            "units": "",
            "description": "Number of primary amines",
            "citations": ["rdkit_website"],
        },
        "fr_N_O": {
            "name": "fr_n_o",
            "dimensionality": "scalar",
            "type": "int",
            "units": "",
            "description": "Number of hydroxylamine groups",
            "citations": ["rdkit_website"],
        },
        "fr_Ndealkylation1": {
            "name": "fr_ndeakylation1",
            "dimensionality": "scalar",
            "type": "int",
            "units": "",
            "description": "Number of XCCNR groups",
            "citations": ["rdkit_website"],
        },
        "fr_Ndealkylation2": {
            "name": "fr_ndeakylation2",
            "dimensionality": "scalar",
            "type": "int",
            "units": "",
            "description": (
                "Number of tert-alicyclic amines (no "
                "heteroatoms, not quinine-like bridged N)"
            ),
            "citations": ["rdkit_website"],
        },
        "fr_Nhpyrrole": {
            "name": "fr_nhpyrrole",
            "dimensionality": "scalar",
            "type": "int",
            "units": "",
            "description": "Number of H-pyrrole nitrogens",
            "citations": ["rdkit_website"],
        },
        "fr_SH": {
            "name": "fr_sh",
            "dimensionality": "scalar",
            "type": "int",
            "units": "",
            "description": "Number of thiol groups",
            "citations": ["rdkit_website"],
        },
        "fr_aldehyde": {
            "name": "fr_aldehyde",
            "dimensionality": "scalar",
            "type": "int",
            "units": "",
            "description": "Number of aldehydes",
            "citations": ["rdkit_website"],
        },
        "fr_alkyl_carbamate": {
            "name": "fr_alkyl_carbamate",
            "dimensionality": "scalar",
            "type": "int",
            "units": "",
            "description": "Number of alkyl carbamates (subject to hydrolysis)",
            "citations": ["rdkit_website"],
        },
        "fr_alkyl_halide": {
            "name": "fr_alkyl_halide",
            "dimensionality": "scalar",
            "type": "int",
            "units": "",
            "description": "Number of alkyl halides",
            "citations": ["rdkit_website"],
        },
        "fr_allylic_oxid": {
            "name": "fr_allylic_oxid",
            "dimensionality": "scalar",
            "type": "int",
            "units": "",
            "description": (
                "Number of allylic oxidation sites excluding " "steroid dienone"
            ),
            "citations": ["rdkit_website"],
        },
        "fr_amide": {
            "name": "fr_amide",
            "dimensionality": "scalar",
            "type": "int",
            "units": "",
            "description": "Number of amides",
            "citations": ["rdkit_website"],
        },
        "fr_amidine": {
            "name": "fr_amidine",
            "dimensionality": "scalar",
            "type": "int",
            "units": "",
            "description": "Number of amidine groups",
            "citations": ["rdkit_website"],
        },
        "fr_aniline": {
            "name": "fr_aniline",
            "dimensionality": "scalar",
            "type": "int",
            "units": "",
            "description": "Number of anilines",
            "citations": ["rdkit_website"],
        },
        "fr_aryl_methyl": {
            "name": "fr_aryl_methyl",
            "dimensionality": "scalar",
            "type": "int",
            "units": "",
            "description": "Number of aryl methyl sites for hydroxylation",
            "citations": ["rdkit_website"],
        },
        "fr_azide": {
            "name": "fr_azide",
            "dimensionality": "scalar",
            "type": "int",
            "units": "",
            "description": "Number of azide groups",
            "citations": ["rdkit_website"],
        },
        "fr_azo": {
            "name": "fr_azo",
            "dimensionality": "scalar",
            "type": "int",
            "units": "",
            "description": "Number of azo groups",
            "citations": ["rdkit_website"],
        },
        "fr_barbitur": {
            "name": "fr_barbitur",
            "dimensionality": "scalar",
            "type": "int",
            "units": "",
            "description": "Number of barbiturate groups",
            "citations": ["rdkit_website"],
        },
        "fr_benzene": {
            "name": "fr_benzene",
            "dimensionality": "scalar",
            "type": "int",
            "units": "",
            "description": "Number of benzene rings",
            "citations": ["rdkit_website"],
        },
        "fr_benzodiazepine": {
            "name": "fr_benzodiazepine",
            "dimensionality": "scalar",
            "type": "int",
            "units": "",
            "description": "Number of benzodiazepines with no additional fused rings",
            "citations": ["rdkit_website"],
        },
        "fr_bicyclic": {
            "name": "fr_bicyclic",
            "dimensionality": "scalar",
            "type": "int",
            "units": "",
            "description": "Number of bicyclic rings",
            "citations": ["rdkit_website"],
        },
        "fr_diazo": {
            "name": "fr_diazo",
            "dimensionality": "scalar",
            "type": "int",
            "units": "",
            "description": "Number of diazo groups",
            "citations": ["rdkit_website"],
        },
        "fr_dihydropyridine": {
            "name": "fr_dihydropyridine",
            "dimensionality": "scalar",
            "type": "int",
            "units": "",
            "description": "Number of dihydropyridines",
            "citations": ["rdkit_website"],
        },
        "fr_epoxide": {
            "name": "fr_epoxide",
            "dimensionality": "scalar",
            "type": "int",
            "units": "",
            "description": "Number of epoxide rings",
            "citations": ["rdkit_website"],
        },
        "fr_ester": {
            "name": "fr_ester",
            "dimensionality": "scalar",
            "type": "int",
            "units": "",
            "description": "Number of ester groups",
            "citations": ["rdkit_website"],
        },
        "fr_ether": {
            "name": "fr_ether",
            "dimensionality": "scalar",
            "type": "int",
            "units": "",
            "description": "Number of ether oxygens (including phenoxy)",
            "citations": ["rdkit_website"],
        },
        "fr_furan": {
            "name": "fr_furan",
            "dimensionality": "scalar",
            "type": "int",
            "units": "",
            "description": "Number of furan rings",
            "citations": ["rdkit_website"],
        },
        "fr_guanido": {
            "name": "fr_guanido",
            "dimensionality": "scalar",
            "type": "int",
            "units": "",
            "description": "Number of guanidine groups",
            "citations": ["rdkit_website"],
        },
        "fr_halogen": {
            "name": "fr_halogen",
            "dimensionality": "scalar",
            "type": "int",
            "units": "",
            "description": "Number of halogens",
            "citations": ["rdkit_website"],
        },
        "fr_hdrzine": {
            "name": "fr_hdrzine",
            "dimensionality": "scalar",
            "type": "int",
            "units": "",
            "description": "Number of hydrazine groups",
            "citations": ["rdkit_website"],
        },
        "fr_hdrzone": {
            "name": "fr_hdrzone",
            "dimensionality": "scalar",
            "type": "int",
            "units": "",
            "description": "Number of hydrazone groups",
            "citations": ["rdkit_website"],
        },
        "fr_imidazole": {
            "name": "fr_imidazole",
            "dimensionality": "scalar",
            "type": "int",
            "units": "",
            "description": "Number of imidazole rings",
            "citations": ["rdkit_website"],
        },
        "fr_imide": {
            "name": "fr_imide",
            "dimensionality": "scalar",
            "type": "int",
            "units": "",
            "description": "Number of imide groups",
            "citations": ["rdkit_website"],
        },
        "fr_isocyan": {
            "name": "fr_isocyan",
            "dimensionality": "scalar",
            "type": "int",
            "units": "",
            "description": "Number of isocyanates",
            "citations": ["rdkit_website"],
        },
        "fr_isothiocyan": {
            "name": "fr_isothiocyan",
            "dimensionality": "scalar",
            "type": "int",
            "units": "",
            "description": "Number of isothiocyanates",
            "citations": ["rdkit_website"],
        },
        "fr_ketone": {
            "name": "fr_ketone",
            "dimensionality": "scalar",
            "type": "int",
            "units": "",
            "description": "Number of ketones",
            "citations": ["rdkit_website"],
        },
        "fr_ketone_Topliss": {
            "name": "fr_ketone_topliss",
            "dimensionality": "scalar",
            "type": "int",
            "units": "",
            "description": (
                "Number of ketones excluding diaryl, a,b-unsaturated "
                "dienones, heteroatom on alpha carbon"
            ),
            "citations": ["rdkit_website"],
        },
        "fr_lactam": {
            "name": "fr_lactam",
            "dimensionality": "scalar",
            "type": "int",
            "units": "",
            "description": "Number of beta lactams",
            "citations": ["rdkit_website"],
        },
        "fr_lactone": {
            "name": "fr_lactone",
            "dimensionality": "scalar",
            "type": "int",
            "units": "",
            "description": "Number of cyclic esters (lactones)",
            "citations": ["rdkit_website"],
        },
        "fr_methoxy": {
            "name": "fr_methoxy",
            "dimensionality": "scalar",
            "type": "int",
            "units": "",
            "description": "Number of methoxy groups -OCH3",
            "citations": ["rdkit_website"],
        },
        "fr_morpholine": {
            "name": "fr_morpholine",
            "dimensionality": "scalar",
            "type": "int",
            "units": "",
            "description": "Number of morpholine rings",
            "citations": ["rdkit_website"],
        },
        "fr_nitrile": {
            "name": "fr_nitrile",
            "dimensionality": "scalar",
            "type": "int",
            "units": "",
            "description": "Number of nitriles",
            "citations": ["rdkit_website"],
        },
        "fr_nitro": {
            "name": "fr_nitro",
            "dimensionality": "scalar",
            "type": "int",
            "units": "",
            "description": "Number of nitro groups",
            "citations": ["rdkit_website"],
        },
        "fr_nitro_arom": {
            "name": "fr_nitro_arom",
            "dimensionality": "scalar",
            "type": "int",
            "units": "",
            "description": "Number of nitro benzene ring substituents",
            "citations": ["rdkit_website"],
        },
        "fr_nitro_arom_nonortho": {
            "name": "fr_nitro_arom_nonortho",
            "dimensionality": "scalar",
            "type": "int",
            "units": "",
            "description": "Number of non-ortho nitro benzene ring substituents",
            "citations": ["rdkit_website"],
        },
        "fr_nitroso": {
            "name": "fr_nitroso",
            "dimensionality": "scalar",
            "type": "int",
            "units": "",
            "description": "Number of nitroso groups, excluding NO2",
            "citations": ["rdkit_website"],
        },
        "fr_oxazole": {
            "name": "fr_oxazole",
            "dimensionality": "scalar",
            "type": "int",
            "units": "",
            "description": "Number of oxazole rings",
            "citations": ["rdkit_website"],
        },
        "fr_oxime": {
            "name": "fr_oxime",
            "dimensionality": "scalar",
            "type": "int",
            "units": "",
            "description": "Number of oxime groups",
            "citations": ["rdkit_website"],
        },
        "fr_para_hydroxylation": {
            "name": "fr_para_hydroxylation",
            "dimensionality": "scalar",
            "type": "int",
            "units": "",
            "description": "Number of para-hydroxylation sites",
            "citations": ["rdkit_website"],
        },
        "fr_phenol": {
            "name": "fr_phenol",
            "dimensionality": "scalar",
            "type": "int",
            "units": "",
            "description": "Number of phenols",
            "citations": ["rdkit_website"],
        },
        "fr_phenol_noOrthoHbond": {
            "name": "fr_phenol_no_ortho_hbond",
            "dimensionality": "scalar",
            "type": "int",
            "units": "",
            "description": (
                "Number of phenolic OH excluding ortho "
                "intramolecular H-bond substituents"
            ),
            "citations": ["rdkit_website"],
        },
        "fr_phos_acid": {
            "name": "fr_phos_acid",
            "dimensionality": "scalar",
            "type": "int",
            "units": "",
            "description": "Number of phosphoric acid groups",
            "citations": ["rdkit_website"],
        },
        "fr_phos_ester": {
            "name": "fr_phos_ester",
            "dimensionality": "scalar",
            "type": "int",
            "units": "",
            "description": "Number of phosphoric ester groups",
            "citations": ["rdkit_website"],
        },
        "fr_piperdine": {
            "name": "fr_piperdine",
            "dimensionality": "scalar",
            "type": "int",
            "units": "",
            "description": "Number of piperdine rings",
            "citations": ["rdkit_website"],
        },
        "fr_piperzine": {
            "name": "fr_piperzine",
            "dimensionality": "scalar",
            "type": "int",
            "units": "",
            "description": "Number of piperzine rings",
            "citations": ["rdkit_website"],
        },
        "fr_priamide": {
            "name": "fr_priamide",
            "dimensionality": "scalar",
            "type": "int",
            "units": "",
            "description": "Number of primary amides",
            "citations": ["rdkit_website"],
        },
        "fr_prisulfonamd": {
            "name": "fr_prisulfonamd",
            "dimensionality": "scalar",
            "type": "int",
            "units": "",
            "description": "Number of primary sulfonamides",
            "citations": ["rdkit_website"],
        },
        "fr_pyridine": {
            "name": "fr_pyridine",
            "dimensionality": "scalar",
            "type": "int",
            "units": "",
            "description": "Number of pyridine rings",
            "citations": ["rdkit_website"],
        },
        "fr_quatN": {
            "name": "fr_quatN",
            "dimensionality": "scalar",
            "type": "int",
            "units": "",
            "description": "Number of quarternary nitrogens",
            "citations": ["rdkit_website"],
        },
        "fr_sulfide": {
            "name": "fr_sulfide",
            "dimensionality": "scalar",
            "type": "int",
            "units": "",
            "description": "Number of thioether groups",
            "citations": ["rdkit_website"],
        },
        "fr_sulfonamd": {
            "name": "fr_sulfonamd",
            "dimensionality": "scalar",
            "type": "int",
            "units": "",
            "description": "Number of sulfonamides",
            "citations": ["rdkit_website"],
        },
        "fr_sulfone": {
            "name": "fr_sulfone",
            "dimensionality": "scalar",
            "type": "int",
            "units": "",
            "description": "Number of sulfone groups",
            "citations": ["rdkit_website"],
        },
        "fr_term_acetylene": {
            "name": "fr_term_acetylene",
            "dimensionality": "scalar",
            "type": "int",
            "units": "",
            "description": "Number of terminal acetylenes",
            "citations": ["rdkit_website"],
        },
        "fr_tetrazole": {
            "name": "fr_tetrazole",
            "dimensionality": "scalar",
            "type": "int",
            "units": "",
            "description": "Number of tetrazole rings",
            "citations": ["rdkit_website"],
        },
        "fr_thiazole": {
            "name": "fr_thiazole",
            "dimensionality": "scalar",
            "type": "int",
            "units": "",
            "description": "Number of thiazole rings",
            "citations": ["rdkit_website"],
        },
        "fr_thiocyan": {
            "name": "fr_thiocyan",
            "dimensionality": "scalar",
            "type": "int",
            "units": "",
            "description": "Number of thiocyanates",
            "citations": ["rdkit_website"],
        },
        "fr_thiophene": {
            "name": "fr_thiophene",
            "dimensionality": "scalar",
            "type": "int",
            "units": "",
            "description": "Number of thiophene rings",
            "citations": ["rdkit_website"],
        },
        "fr_unbrch_alkane": {
            "name": "fr_unbrch_alkane",
            "dimensionality": "scalar",
            "type": "int",
            "units": "",
            "description": (
                "Number of unbranched alkanes of at least "
                "4 members (excludes halogenated alkanes)"
            ),
            "citations": ["rdkit_website"],
        },
        "fr_urea": {
            "name": "fr_urea",
            "dimensionality": "scalar",
            "type": "int",
            "units": "",
            "description": "Number of urea groups",
            "citations": ["rdkit_website"],
        },
    },
}
